==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetRecommenderConfigurationRequest(recommenderId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest = {
    import GetRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
      .builder()
      .recommenderId(__string.unwrap(recommenderId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.GetRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object GetRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetRecommenderConfigurationRequest =
      zio.aws.pinpoint.model.GetRecommenderConfigurationRequest(recommenderId)
    def recommenderId: __string
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.recommenderId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-pinpoint_3-5.17.267.1-sources.jar: zio/aws/pinpoint/model/GetRecommenderConfigurationRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetRecommenderConfigurationRequest(recommenderId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest = {
    import GetRecommenderConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
      .builder()
      .recommenderId(recommenderId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly =
    zio.aws.pinpoint.model.GetRecommenderConfigurationRequest
      .wrap(buildAwsValue())
}
object GetRecommenderConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetRecommenderConfigurationRequest =
      zio.aws.pinpoint.model.GetRecommenderConfigurationRequest(recommenderId)
    def recommenderId: __string
    def getRecommenderId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(recommenderId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ) extends zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly {
    override val recommenderId: __string = impl.recommenderId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetRecommenderConfigurationRequest
  ): zio.aws.pinpoint.model.GetRecommenderConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
